Package Reference Documentation
===============================
The following classes and methods form the `rampedpyrox` package:

Ramped PyrOx classes
--------------------
.. autosummary::
	:toctree: _generated/

	rampedpyrox.RpoThermogram
	rampedpyrox.Daem
	rampedpyrox.EnergyComplex
	rampedpyrox.RpoIsotopes

Ramped PyrOx methods
--------------------
.. autosummary::
	:toctree: _generated/

	rampedpyrox.assert_len
	rampedpyrox.calc_L_curve
	rampedpyrox.derivatize
	rampedpyrox.extract_moments
	rampedpyrox.plot_tg_isotopes

References
----------
The following references were used during creation of the core ``rampedpyrox``
pacakge or provide information regarding the choice of user-inputted parameters 
(*i.e.* `omega`, `lambda`, and `DE`).

[1] R.L Braun and A.K. Burnham (1987) Analysis of chemical reaction kinetics
using a distribution of activation energies and simpler models.
*Energy & Fuels*, **1**, 153-161.

[2] B. Cramer (2004) Methane generation from coal during open system 
pyrolysis investigated by isotope specific, Gaussian distributed reaction
kinetics. *Organic Geochemistry*, **35**, 379-392.

[3] V. Dieckmann (2005) Modeling petroleum formation from heterogeneous
source rocks: The influence of frequency factors on activation energy
distribution and geological prediction. *Marine and Petroleum Geology*,
**22**, 375-390.

[4] D.C. Forney and D.H. Rothman (2012) Common structure in the
heterogeneity of plant-matter decay. *Journal of the Royal Society
Interface*, rsif.2012.0122.

[5] D.C. Forney and D.H. Rothman (2012) Inverse method for calculating
respiration rates from decay time series. *Biogeosciences*, **9**,
3601-3612.

[6] P.C. Hansen (1994) Regularization tools: A Matlab package for analysis and
solution of discrete ill-posed problems. *Numerical Algorithms*, **6**,
1-35.

[7] J.D. Hemingway et al. (2017) Assessing the blank carbon
contribution, isotope mass balance, and kinetic isotope fractionation of 
the ramped pyrolysis/oxidation instrument at NOSAMS. *Radiocarbon*, 
**59**, 179-193.

[8] C.C. Lakshmananan et al. (1991) Implications of multiplicity in
kinetic parameters to petroleum exploration: Distributed activation
energy models. *Energy & Fuels*, **5**, 110-117.

[9] Rosenheim et al. (2008) Antarctic sediment chronology by 
programmed-temperature pyrolysis: Methodology and data treatment. 
*Geochemistry, Geophysics, Geosystems*, **9(4)**, GC001816.

[10] J.E. White et al. (2011) Biomass pyrolysis kinetics: A comparative
critical review with relevant agricultural residue case studies.
*Journal of Analytical and Applied Pyrolysis*, **91**, 1-33.
